from setuptools import setup, find_packages

setup(
    name='rentUtility',
    version='0.1.0',
    description='A Python library for rental based system and perform important calculations',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Ayush Jadhav',
    author_email='jadhavayush2020@email.com',
    url='https://github.com/Ayush-NCI/rentaltility',
    packages=find_packages(),
    license='MIT',
    
)
